==> acquia_search-3.0.2.tar.gz: acquia_search/src/Helper/Storage.php <==
<?php

namespace Drupal\acquia_search\Helper;

/**
 * Class Storage.
 *
 * Centralized place for accessing and updating Acquia Search Solr settings.
 */
class Storage {

  /**
   * Returns Acquia Search API host.
   *
   * To manage Acquia Search.
   *
   * @return string
   *   Acquia Search API host.
   */
  public static function getApiHost() {
    return \Drupal::config('acquia_search.settings')->get('api_host') ?? 'https://api.sr-prod02.acquia.com';
  }

  /**
   * Returns Acquia Connector key.
   *
   * @return string
   *   Acquia Connector key.
   */
  public static function getApiKey() {
    return \Drupal::state()->get('acquia_search.api_key', '');
  }

  /**
   * Returns Acquia Subscription identifier.
   *
   * @return string
   *   Acquia Subscription identifier.
   */
  public static function getIdentifier(): string {
    return \Drupal::state()->get('acquia_search.identifier', '');
  }

  /**
   * Returns Acquia Application UUID.
   *
   * @return string
   *   Acquia Application UUID.
   */
  public static function getUuid(): string {
    return \Drupal::state()->get('acquia_search.uuid', '');
  }

  /**
   * Get Acquia Search Solr module version.
   *
   * @return string
   *   Acquia Search Solr module version.
   */
  public static function getVersion(): string {

    if (!$version = \Drupal::state()->get('acquia_search.version')) {
      $info = \Drupal::service('extension.list.module')->getExtensionInfo('acquia_search');
      // Send the version, or at least the core compatibility as a fallback.
      $version = (string) ($info['version'] ?? \Drupal::VERSION);
      \Drupal::state()->set('acquia_search.version', $version);
    }

    return $version;

  }

  /**
   * Get a search core override.
   *
   * The Acquia Search Solr module tries to use this core before any of auto
   * detected cores in case if it's set in the site configuration.
   *
   * @return string|null
   *   Acquia Search Solr search core id.
   */
  public static function getSearchCoreOverride(): ?string {

    return \Drupal::config('acquia_search.settings')->get('override_search_core');

  }

  /**
   * Get extract query handler option.
   *
   * @return string
   *   Extract query handler option.
   *
   * @see \Drupal\acquia_search\Plugin\SolrConnector\SearchApiSolrAcquiaConnector::getExtractQuery()
   */
  public static function getExtractQueryHandlerOption(): string {

    return \Drupal::config('acquia_search.settings')->get('extract_query_handler_option') ?? 'update/extract';

  }

  /**
   * Determine if the read-only mode is enabled.
   *
   * @return bool
   *   TRUE if the read-only mode forced by the site configuration.
   */
  public static function isReadOnly(): bool {

    return !empty(\Drupal::config('acquia_search.settings')->get('read_only'));

  }

  /**
   * Updates Acquia Search API host.
   *
   * @param string $value
   *   Acquia Search API host.
   */
  public function setApiHost($value) {
    \Drupal::configFactory()->getEditable('acquia_search.settings')->set('api_host', $value)->save();
  }

  /**
   * Updates Acquia Search API key.
   *
   * @param string $value
   *   Acquia Search API key.
   */
  public function setApiKey($value) {
    \Drupal::state()->set('acquia_search.api_key', $value);
  }

  /**
   * Updates Acquia Subscription identifier.
   *
   * @param string $value
   *   Acquia Subscription identifier.
   */
  public function setIdentifier($value) {
    \Drupal::state()->set('acquia_search.identifier', $value);
  }

  /**
   * Updates Acquia Application UUID.
   *
   * @param string $value
   *   Acquia Application UUID.
   */
  public function setUuid($value) {
    \Drupal::state()->set('acquia_search.uuid', $value);
  }

  /**
   * Deletes all data stored in State.
   */
  public function deleteAllData() {
    \Drupal::state()->deleteMultiple([
      'acquia_search.api_key',
      'acquia_search.identifier',
      'acquia_search.uuid',
      'acquia_search.version',
    ]);
  }

}

==> acquia_search-3.0.9.tar.gz: acquia_search/src/Helper/Storage.php <==
<?php

namespace Drupal\acquia_search\Helper;

/**
 * Class Storage.
 *
 * Centralized place for accessing and updating Acquia Search Solr settings.
 */
class Storage {

  /**
   * Gets a setting from Acquia Connector.
   *
   * @param string $key
   *   The key.
   *
   * @return string|null
   *   The value.
   */
  private static function getConnectorSetting($key) {
    if (!\Drupal::moduleHandler()->moduleExists('acquia_connector')) {
      return '';
    }
    if (\Drupal::hasService('acquia_connector.subscription')) {
      /** @var \Drupal\acquia_connector\Subscription $subscription */
      $subscription = \Drupal::service('acquia_connector.subscription');
      if ($key === 'identifier') {
        return $subscription->getSettings()->getIdentifier() ?? '';
      }
      if ($key === 'key') {
        return $subscription->getSettings()->getSecretKey() ?? '';
      }
      if ($key === 'uuid') {
        return $subscription->getSettings()->getApplicationUuid() ?? '';
      }
      return '';
    }

    if ($key === 'identifier') {
      return \Drupal::state()->get('acquia_connector.identifier') ?? '';
    }
    if ($key === 'key') {
      return \Drupal::state()->get('acquia_connector.key') ?? '';
    }
    if ($key === 'uuid') {
      $subscription_data = \Drupal::state()->get('acquia_subscription_data', []);
      return $subscription_data['uuid'] ?? '';
    }
    return '';
  }

  /**
   * Gets value, with fallback to Acquia Connector.
   *
   * @param string $key
   *   The value key.
   * @param string $connector_key
   *   The connector value key.
   *
   * @return string|null
   *   The value.
   */
  private static function getValue($key, $connector_key) {
    $value = \Drupal::state()->get("acquia_search.$key", '');
    if (empty($value)) {
      $value = self::getConnectorSetting($connector_key);
    }
    return $value;
  }

  /**
   * Returns Acquia Search API host.
   *
   * To manage Acquia Search.
   *
   * @return string
   *   Acquia Search API host.
   */
  public static function getApiHost() {
    return \Drupal::config('acquia_search.settings')->get('api_host') ?? 'https://api.sr-prod02.acquia.com';
  }

  /**
   * Returns Acquia Connector key.
   *
   * @return string
   *   Acquia Connector key.
   */
  public static function getApiKey() {
    return self::getValue('api_key', 'key');
  }

  /**
   * Returns Acquia Subscription identifier.
   *
   * @return string
   *   Acquia Subscription identifier.
   */
  public static function getIdentifier(): string {
    return self::getValue('identifier', 'identifier');
  }

  /**
   * Returns Acquia Application UUID.
   *
   * @return string
   *   Acquia Application UUID.
   */
  public static function getUuid(): string {
    return self::getValue('uuid', 'uuid');
  }

  /**
   * Get Acquia Search Solr module version.
   *
   * @return string
   *   Acquia Search Solr module version.
   */
  public static function getVersion(): string {

    if (!$version = \Drupal::state()->get('acquia_search.version')) {
      $info = \Drupal::service('extension.list.module')->getExtensionInfo('acquia_search');
      // Send the version, or at least the core compatibility as a fallback.
      $version = (string) ($info['version'] ?? \Drupal::VERSION);
      \Drupal::state()->set('acquia_search.version', $version);
    }

    return $version;

  }

  /**
   * Get a search core override.
   *
   * The Acquia Search Solr module tries to use this core before any of auto
   * detected cores in case if it's set in the site configuration.
   *
   * @return string|null
   *   Acquia Search Solr search core id.
   */
  public static function getSearchCoreOverride(): ?string {

    return \Drupal::config('acquia_search.settings')->get('override_search_core');

  }

  /**
   * Get extract query handler option.
   *
   * @return string
   *   Extract query handler option.
   *
   * @see \Drupal\acquia_search\Plugin\SolrConnector\SearchApiSolrAcquiaConnector::getExtractQuery()
   */
  public static function getExtractQueryHandlerOption(): string {

    return \Drupal::config('acquia_search.settings')->get('extract_query_handler_option') ?? 'update/extract';

  }

  /**
   * Determine if the read-only mode is enabled.
   *
   * @return bool
   *   TRUE if the read-only mode forced by the site configuration.
   */
  public static function isReadOnly(): bool {

    return !empty(\Drupal::config('acquia_search.settings')->get('read_only'));

  }

  /**
   * Updates Acquia Search API host.
   *
   * @param string $value
   *   Acquia Search API host.
   */
  public function setApiHost($value) {
    \Drupal::configFactory()->getEditable('acquia_search.settings')->set('api_host', $value)->save();
  }

  /**
   * Updates Acquia Search API key.
   *
   * @param string $value
   *   Acquia Search API key.
   */
  public function setApiKey($value) {
    \Drupal::state()->set('acquia_search.api_key', $value);
  }

  /**
   * Updates Acquia Subscription identifier.
   *
   * @param string $value
   *   Acquia Subscription identifier.
   */
  public function setIdentifier($value) {
    \Drupal::state()->set('acquia_search.identifier', $value);
  }

  /**
   * Updates Acquia Application UUID.
   *
   * @param string $value
   *   Acquia Application UUID.
   */
  public function setUuid($value) {
    \Drupal::state()->set('acquia_search.uuid', $value);
  }

  /**
   * Deletes all data stored in State.
   */
  public function deleteAllData() {
    \Drupal::state()->deleteMultiple([
      'acquia_search.api_key',
      'acquia_search.identifier',
      'acquia_search.uuid',
      'acquia_search.version',
    ]);
  }

}
